------------------------------------------------------------------------------
--                                                                          --
--                           GNAT RAVENSCAR for NXT                         --
--                                                                          --
--                       Copyright (C) 2010, AdaCore                        --
--                                                                          --
-- This is free software; you can  redistribute it  and/or modify it under  --
-- terms of the  GNU General Public License as published  by the Free Soft- --
-- ware  Foundation;  either version 2,  or (at your option) any later ver- --
-- sion. This is distributed in the hope that it will be useful, but WITH-  --
-- OUT ANY WARRANTY;  without even the  implied warranty of MERCHANTABILITY --
-- or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License --
-- for  more details.  You should have  received  a copy of the GNU General --
-- Public License  distributed with GNARL; see file COPYING.  If not, write --
-- to  the Free Software Foundation,  59 Temple Place - Suite 330,  Boston, --
-- MA 02111-1307, USA.                                                      --
--                                                                          --
-- As a special exception,  if other files  instantiate  generics from this --
-- unit, or you link  this unit with other files  to produce an executable, --
-- this  unit  does not  by itself cause  the resulting  executable  to  be --
-- covered  by the  GNU  General  Public  License.  This exception does not --
-- however invalidate  any other reasons why  the executable file  might be --
-- covered by the  GNU Public License.                                      --
--                                                                          --
------------------------------------------------------------------------------

--  Low-level driver for the AVR.  Use Nxt.Avrtask for higher level.

with Interfaces; use Interfaces;
with Nxt.Avr_Types; use Nxt.Avr_Types;

package Nxt.Avr is
   procedure Init;
   --  Initialize the device.

   procedure Power_Down;
   --  Set power down in the frame.

   procedure Read_Data;
   --  Read a message from the AVR.

   function Get_Button return Button_Kind;
   --  Extract buttons state from the message.

   function Get_Sensor (Sensor : Sensor_Id) return Unsigned_16;
   --  Get the value of SENSOR.

   procedure Set_Motor (Motor : Motor_Id; Pwm : Pwm_Type; Break : Boolean);
   --  Set parameters for motor MOTOR in the frame.

   procedure Send_Frame;
   --  Send the frame to the AVR.
end Nxt.Avr;
