------------------------------------------------------------------------------
--                                                                          --
--                           GNAT RAVENSCAR for NXT                         --
--                                                                          --
--                       Copyright (C) 2010, AdaCore                        --
--                                                                          --
-- This is free software; you can  redistribute it  and/or modify it under  --
-- terms of the  GNU General Public License as published  by the Free Soft- --
-- ware  Foundation;  either version 2,  or (at your option) any later ver- --
-- sion. This is distributed in the hope that it will be useful, but WITH-  --
-- OUT ANY WARRANTY;  without even the  implied warranty of MERCHANTABILITY --
-- or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License --
-- for  more details.  You should have  received  a copy of the GNU General --
-- Public License  distributed with GNARL; see file COPYING.  If not, write --
-- to  the Free Software Foundation,  59 Temple Place - Suite 330,  Boston, --
-- MA 02111-1307, USA.                                                      --
--                                                                          --
-- As a special exception,  if other files  instantiate  generics from this --
-- unit, or you link  this unit with other files  to produce an executable, --
-- this  unit  does not  by itself cause  the resulting  executable  to  be --
-- covered  by the  GNU  General  Public  License.  This exception does not --
-- however invalidate  any other reasons why  the executable file  might be --
-- covered by the  GNU Public License.                                      --
--                                                                          --
------------------------------------------------------------------------------

--  Periodic task that communicate with the AVR.

with Ada.Real_Time; use Ada.Real_Time;

package body Nxt.Avrtask is
   task Avr is
      pragma Storage_Size (4096);
   end Avr;

   task body Avr is
      T : Time;
      Td : constant Time_Span := Milliseconds (10);
      Power_Cnt : Natural := 0;
   begin
      Nxt.Avr.Init;

      T := Clock + Milliseconds (20);
      delay until T;

      loop
         --  Send a frame.
         T := T + Td;
         delay until T;
         Nxt.Avr.Send_Frame;

         --  Receive a frame.
         T := T + Td;
         delay until T;
         Nxt.Avr.Read_Data;

         --  Decode buttons.
         Button := Nxt.Avr.Get_Button;

         --  Forced power off.
         if Button = Button_Power then
            Power_Cnt := Power_Cnt + 1;
            if Power_Cnt = 150 then
               Power_Down;
            end if;
         else
            Power_Cnt := 0;
         end if;
      end loop;
   end Avr;
end Nxt.Avrtask;
