------------------------------------------------------------------------------
--                                                                          --
--                           GNAT RAVENSCAR for NXT                         --
--                                                                          --
--                       Copyright (C) 2010, AdaCore                        --
--                                                                          --
-- This is free software; you can  redistribute it  and/or modify it under  --
-- terms of the  GNU General Public License as published  by the Free Soft- --
-- ware  Foundation;  either version 2,  or (at your option) any later ver- --
-- sion. This is distributed in the hope that it will be useful, but WITH-  --
-- OUT ANY WARRANTY;  without even the  implied warranty of MERCHANTABILITY --
-- or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License --
-- for  more details.  You should have  received  a copy of the GNU General --
-- Public License  distributed with GNARL; see file COPYING.  If not, write --
-- to  the Free Software Foundation,  59 Temple Place - Suite 330,  Boston, --
-- MA 02111-1307, USA.                                                      --
--                                                                          --
-- As a special exception,  if other files  instantiate  generics from this --
-- unit, or you link  this unit with other files  to produce an executable, --
-- this  unit  does not  by itself cause  the resulting  executable  to  be --
-- covered  by the  GNU  General  Public  License.  This exception does not --
-- however invalidate  any other reasons why  the executable file  might be --
-- covered by the  GNU Public License.                                      --
--                                                                          --
------------------------------------------------------------------------------

with Nxt.Bt; use Nxt.Bt;
with Nxt.Display;

package body Nxt.Bc4 is

   Flag_Trace : constant Boolean := False;

   Tx_Packet : Packet_Type (Packet_Len_Type);
   Rx_Packet : Packet_Type (Packet_Len_Type);

   procedure Send_Packet (Pkt : Packet_Type) is
      use Nxt.Display;
      Checksum : Unsigned_32;
      B : Unsigned_8;
   begin
      Checksum := 0;
      Tx_Packet (0) := Pkt'Length + 2;
      for I in 0 .. Pkt'Length - 1 loop
         B := Pkt (Pkt'First + I);
         Tx_Packet (I + 1) := B;
         Checksum := Checksum - Unsigned_32 (B);
      end loop;
      Tx_Packet (Pkt'Length + 1) :=
        Unsigned_8 (Shift_Right (Checksum, 8) and 16#ff#);
      Tx_Packet (Pkt'Length + 2) :=
        Unsigned_8 (Shift_Right (Checksum, 0) and 16#ff#);

      if Flag_Trace then
         Put ("Snd:");
         for I in 0 .. Pkt'Length + 2 loop
            Put (' ');
            Put_Hex (Tx_Packet (I));
         end loop;
         Newline;
      end if;

      Send (Tx_Packet'Address, Pkt'Length + 3);
   end Send_Packet;

   procedure Recv_Packet (Pkt : out Packet_Type) is
      use Nxt.Display;
      Len : Natural;
      Checksum : Unsigned_32;
      B : Unsigned_8;
   begin
      pragma Assert (Pkt'Length >= 2);

      Rx_Packet (0) := 0;
      Recv (Rx_Packet'Address);
      Len := Natural (Rx_Packet (0));
      Pkt (Pkt'First) := 0;
      if Len = 0 then
         return;
      end if;

      if Len < 3 then
         if Flag_Trace then
            Put_Line ("bad len");
         end if;
         return;
      end if;

      if Flag_Trace then
         Put ("Rcv:");
         for I in 0 .. len loop
            Put (' ');
            Put_Hex (Rx_Packet (I));
         end loop;
         Newline;
      end if;

      --  Compute the checksum.
      Checksum := 0;
      for I in 0 .. Len - 2 loop
         B := Rx_Packet (I);
         if I < Pkt'Length then
            Pkt (Pkt'First + I) := B;
         end if;
         Checksum := Checksum + Unsigned_32 (B);
      end loop;
      Checksum := Checksum
        + Shift_Left (Unsigned_32 (Rx_Packet (Len - 1)), 8)
        + Shift_Left (Unsigned_32 (Rx_Packet (Len)), 0);

      if (Checksum and 16#ffff#) /= 0 then
         if Flag_Trace then
            Put_Line ("bad cksum");
         end if;
         --  Discard the packet.
         Pkt (Pkt'First) := 0;
      end if;
   end Recv_Packet;

end Nxt.Bc4;
