------------------------------------------------------------------------------
--                                                                          --
--                           GNAT RAVENSCAR for NXT                         --
--                                                                          --
--                       Copyright (C) 2010, AdaCore                        --
--                                                                          --
-- This is free software; you can  redistribute it  and/or modify it under  --
-- terms of the  GNU General Public License as published  by the Free Soft- --
-- ware  Foundation;  either version 2,  or (at your option) any later ver- --
-- sion. This is distributed in the hope that it will be useful, but WITH-  --
-- OUT ANY WARRANTY;  without even the  implied warranty of MERCHANTABILITY --
-- or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License --
-- for  more details.  You should have  received  a copy of the GNU General --
-- Public License  distributed with GNARL; see file COPYING.  If not, write --
-- to  the Free Software Foundation,  59 Temple Place - Suite 330,  Boston, --
-- MA 02111-1307, USA.                                                      --
--                                                                          --
-- As a special exception,  if other files  instantiate  generics from this --
-- unit, or you link  this unit with other files  to produce an executable, --
-- this  unit  does not  by itself cause  the resulting  executable  to  be --
-- covered  by the  GNU  General  Public  License.  This exception does not --
-- however invalidate  any other reasons why  the executable file  might be --
-- covered by the  GNU Public License.                                      --
--                                                                          --
------------------------------------------------------------------------------

--  High-level bluetooth driver.

with System; use System;
with Nxt.Bt;
with Interfaces; use Interfaces;

package Nxt.Bluetooth is
   type Address_Type is array (0 .. 6) of Unsigned_8;
   --  An address.

   type Name_Type is array (0 .. 15) of Unsigned_8;
   --  Friendly name.

   type Class_Type is array (0 .. 3) of Unsigned_8;
   --  Class and service.

   type Pin_Type is array (0 .. 15) of Unsigned_8;
   --  Pin code.

   type Device_Type is record
      Addr : Address_Type;
      Name : Name_Type;
      Class : Class_Type;
   end record;

   type Device_Array is array (Natural range <>) of Device_Type;

   --  Note: all procedures are blocking (ie they use delay).

   procedure Init;
   --  Initialize the device.  Must be done before any other operation.

   procedure String_To_Name (Str : String; Name : out Name_Type);
   --  Convert a string to a name.  Append necessary NUL byte.
   --  STR may be cut if too long.

   procedure Set_Friendly_Name (Name : Name_Type);
   --  Define the friendly name.

   procedure Get_Known_Peers (Devs : out Device_Array; Len : out Natural);
   --  Get the list of known peers.

   procedure Inquiry (Timeout_Sec : Natural;
                      Devs : out Device_Array; Len : out Natural);
   --  Find discoverable devices.

   procedure Set_Discoverable (On : Boolean);
   --  Make the device discoverable (or not).

   procedure Add_Known_Device (Dev : Device_Type; Success : out Boolean);
   --  Add a device to the known peer list.

   procedure Accept_Connection
     (Pin : Pin_Type;
      Addr : out Address_Type; Success : out Boolean);
   --  Wait for a connection.

   procedure Connect (Addr : Address_Type; Success : out Boolean);
   --  Connect to a device.

   procedure Send_Data (Msg : Address; Len : Natural)
     renames Nxt.Bt.Send;
   procedure Recv_Data (Msg : Address)
     renames Nxt.Bt.Recv;
   --  Send and receive data packet.
end Nxt.Bluetooth;
