------------------------------------------------------------------------------
--                                                                          --
--                           GNAT RAVENSCAR for NXT                         --
--                                                                          --
--                       Copyright (C) 2010, AdaCore                        --
--                                                                          --
-- This is free software; you can  redistribute it  and/or modify it under  --
-- terms of the  GNU General Public License as published  by the Free Soft- --
-- ware  Foundation;  either version 2,  or (at your option) any later ver- --
-- sion. This is distributed in the hope that it will be useful, but WITH-  --
-- OUT ANY WARRANTY;  without even the  implied warranty of MERCHANTABILITY --
-- or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License --
-- for  more details.  You should have  received  a copy of the GNU General --
-- Public License  distributed with GNARL; see file COPYING.  If not, write --
-- to  the Free Software Foundation,  59 Temple Place - Suite 330,  Boston, --
-- MA 02111-1307, USA.                                                      --
--                                                                          --
-- As a special exception,  if other files  instantiate  generics from this --
-- unit, or you link  this unit with other files  to produce an executable, --
-- this  unit  does not  by itself cause  the resulting  executable  to  be --
-- covered  by the  GNU  General  Public  License.  This exception does not --
-- however invalidate  any other reasons why  the executable file  might be --
-- covered by the  GNU Public License.                                      --
--                                                                          --
------------------------------------------------------------------------------

--  Definitions and binding for the bluetooth module.
--  ??? should be part of nxt.bc4 ?

with Interfaces; use Interfaces;
with System; use System;
with Nxt.Lejos;

package Nxt.Bt is
   --  Bluetooth module messages.
   MSG_BEGIN_INQUIRY               : constant Unsigned_8 := 0;
   MSG_CANCEL_INQUIRY              : constant Unsigned_8 := 1;
   MSG_CONNECT                     : constant Unsigned_8 := 2;
   MSG_OPEN_PORT                   : constant Unsigned_8 := 3;
   MSG_LOOKUP_NAME                 : constant Unsigned_8 := 4;
   MSG_ADD_DEVICE                  : constant Unsigned_8 := 5;
   MSG_REMOVE_DEVICE               : constant Unsigned_8 := 6;
   MSG_DUMP_LIST                   : constant Unsigned_8 := 7;
   MSG_CLOSE_CONNECTION            : constant Unsigned_8 := 8;
   MSG_ACCEPT_CONNECTION           : constant Unsigned_8 := 9;
   MSG_PIN_CODE                    : constant Unsigned_8 := 10;
   MSG_OPEN_STREAM                 : constant Unsigned_8 := 11;
   MSG_START_HEART                 : constant Unsigned_8 := 12;
   MSG_HEARTBEAT                   : constant Unsigned_8 := 13;
   MSG_INQUIRY_RUNNING             : constant Unsigned_8 := 14;
   MSG_INQUIRY_RESULT              : constant Unsigned_8 := 15;
   MSG_INQUIRY_STOPPED             : constant Unsigned_8 := 16;
   MSG_LOOKUP_NAME_RESULT          : constant Unsigned_8 := 17;
   MSG_LOOKUP_NAME_FAILURE         : constant Unsigned_8 := 18;
   MSG_CONNECT_RESULT              : constant Unsigned_8 := 19;
   MSG_RESET_INDICATION            : constant Unsigned_8 := 20;
   MSG_REQUEST_PIN_CODE            : constant Unsigned_8 := 21;
   MSG_REQUEST_CONNECTION          : constant Unsigned_8 := 22;
   MSG_LIST_RESULT                 : constant Unsigned_8 := 23;
   MSG_LIST_ITEM                   : constant Unsigned_8 := 24;
   MSG_LIST_DUMP_STOPPED           : constant Unsigned_8 := 25;
   MSG_CLOSE_CONNECTION_RESULT     : constant Unsigned_8 := 26;
   MSG_PORT_OPEN_RESULT            : constant Unsigned_8 := 27;
   MSG_SET_DISCOVERABLE            : constant Unsigned_8 := 28;
   MSG_CLOSE_PORT                  : constant Unsigned_8 := 29;
   MSG_CLOSE_PORT_RESULT           : constant Unsigned_8 := 30;
   MSG_PIN_CODE_ACK                : constant Unsigned_8 := 31;
   MSG_DISCOVERABLE_ACK            : constant Unsigned_8 := 32;
   MSG_SET_FRIENDLY_NAME           : constant Unsigned_8 := 33;
   MSG_SET_FRIENDLY_NAME_ACK       : constant Unsigned_8 := 34;
   MSG_GET_LINK_QUALITY            : constant Unsigned_8 := 35;
   MSG_LINK_QUALITY_RESULT         : constant Unsigned_8 := 36;
   MSG_SET_FACTORY_SETTINGS        : constant Unsigned_8 := 37;
   MSG_SET_FACTORY_SETTINGS_ACK    : constant Unsigned_8 := 38;
   MSG_GET_LOCAL_ADDR              : constant Unsigned_8 := 39;
   MSG_GET_LOCAL_ADDR_RESULT       : constant Unsigned_8 := 40;
   MSG_GET_FRIENDLY_NAME           : constant Unsigned_8 := 41;
   MSG_GET_DISCOVERABLE            : constant Unsigned_8 := 42;
   MSG_GET_PORT_OPEN               : constant Unsigned_8 := 43;
   MSG_GET_FRIENDLY_NAME_RESULT    : constant Unsigned_8 := 44;
   MSG_GET_DISCOVERABLE_RESULT     : constant Unsigned_8 := 45;
   MSG_GET_PORT_OPEN_RESULT        : constant Unsigned_8 := 46;
   MSG_GET_VERSION                 : constant Unsigned_8 := 47;
   MSG_GET_VERSION_RESULT          : constant Unsigned_8 := 48;
   MSG_GET_BRICK_STATUSBYTE_RESULT : constant Unsigned_8 := 49;
   MSG_SET_BRICK_STATUSBYTE_RESULT : constant Unsigned_8 := 50;
   MSG_GET_BRICK_STATUSBYTE        : constant Unsigned_8 := 51;
   MSG_SET_BRICK_STATUSBYTE        : constant Unsigned_8 := 52;
   MSG_GET_OPERATING_MODE          : constant Unsigned_8 := 53;
   MSG_SET_OPERATING_MODE          : constant Unsigned_8 := 54;
   MSG_SET_OPERATING_MODE_RESULT   : constant Unsigned_8 := 55;
   MSG_GET_CONNECTION_STATUS       : constant Unsigned_8 := 56;
   MSG_CONNECTION_STATUS_RESULT    : constant Unsigned_8 := 57;
   MSG_GOTO_DFUMODE                : constant Unsigned_8 := 58;

   STREAM_BREAKING_MODE   : constant Unsigned_8 := 0;
   DONT_BREAK_STREAM_MODE : constant Unsigned_8 := 1;

   procedure Init;
   pragma Import (C, Init, "bt_init");

   procedure Reset;
   pragma Import (C, Reset, "bt_reset");

   procedure Send (Msg : Address; Len : Natural);
   pragma Import (C, Send, "bt_send");

   procedure Recv (Msg : Address);
   pragma Import (C, Recv, "bt_receive");

   procedure Mode_Cmd;
   pragma Import (C, Mode_Cmd, "bt_clear_arm7_cmd");

   procedure Mode_Data;
   pragma Import (C, Mode_Data, "bt_set_arm7_cmd");

   pragma Linker_Options ("bt.o");
end Nxt.Bt;
