------------------------------------------------------------------------------
--                                                                          --
--                  GNAT RUN-TIME LIBRARY (GNARL) COMPONENTS                --
--                                                                          --
--      S Y S T E M . B B . P E R I P H E R A L S . R E G I S T E R S       --
--                                                                          --
--                                  S p e c                                 --
--                                                                          --
--        Copyright (C) 1999-2002 Universidad Politecnica de Madrid         --
--             Copyright (C) 2003-2006 The European Space Agency            --
--                     Copyright (C) 2003-2010, AdaCore                     --
--                                                                          --
-- GNARL is free software; you can  redistribute it  and/or modify it under --
-- terms of the  GNU General Public License as published  by the Free Soft- --
-- ware  Foundation;  either version 2,  or (at your option) any later ver- --
-- sion. GNARL is distributed in the hope that it will be useful, but WITH- --
-- OUT ANY WARRANTY;  without even the  implied warranty of MERCHANTABILITY --
-- or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License --
-- for  more details.  You should have  received  a copy of the GNU General --
-- Public License  distributed with GNARL; see file COPYING.  If not, write --
-- to  the Free Software Foundation,  59 Temple Place - Suite 330,  Boston, --
-- MA 02111-1307, USA.                                                      --
--                                                                          --
-- As a special exception,  if other files  instantiate  generics from this --
-- unit, or you link  this unit with other files  to produce an executable, --
-- this  unit  does not  by itself cause  the resulting  executable  to  be --
-- covered  by the  GNU  General  Public  License.  This exception does not --
-- however invalidate  any other reasons why  the executable file  might be --
-- covered by the  GNU Public License.                                      --
--                                                                          --
-- GNARL was developed by the GNARL team at Florida State University.       --
-- Extensive contributions were provided by Ada Core Technologies, Inc.     --
--                                                                          --
-- The porting of GNARL to bare board  targets was initially  developed  by --
-- the Real-Time Systems Group at the Technical University of Madrid.       --
--                                                                          --
------------------------------------------------------------------------------

--  This package provides the appropriate mapping for the system registers.

pragma Restrictions (No_Elaboration_Code);

with Interfaces;

package System.BB.Peripherals.Registers is
   pragma Preelaborate;

   subtype Register_32 is Interfaces.Unsigned_32;

   --  Peripheral identifiers

   AT91C_ID_FIQ  : constant := 0;
   AT91C_ID_SYS  : constant := 1;
   AT91C_ID_PIOA : constant := 2;
   AT91C_ID_ADC  : constant := 4;
   AT91C_ID_SPI  : constant := 5;
   AT91C_ID_US0  : constant := 6;
   AT91C_ID_US1  : constant := 7;
   AT91C_ID_SCC  : constant := 8;
   AT91C_ID_TWI  : constant := 9;
   AT91C_ID_PWMC : constant := 10;
   AT91C_ID_UDP  : constant := 11;

   --  AIC

   --  AIC SMR.

   type AIC_SMR_Array is array (0 .. 31) of Register_32;
   AIC_SMR : AIC_SMR_Array;
   for AIC_SMR'Address use System'To_Address (16#Ffff_F000#);

   --  AIC SVR

   type AIC_SVR_Array is array (0 .. 31) of Register_32;
   AIC_SVR : AIC_SVR_Array;
   for AIC_SVR'Address use System'To_Address (16#Ffff_F080#);

   --  AIC IVR

   AIC_IVR : Register_32;
   for AIC_IVR'Address use System'To_Address (16#Ffff_F100#);

   --  AIC FVR

   AIC_FVR : Register_32;
   for AIC_FVR'Address use System'To_Address (16#Ffff_F104#);

   --  AIC ISR

   AIC_ISR : Register_32;
   for AIC_ISR'Address use System'To_Address (16#Ffff_F108#);

   --  AIC IPR

   AIC_IPR : Register_32;
   for AIC_IPR'Address use System'To_Address (16#Ffff_F10C#);

   --  AIC IMR

   AIC_IMR : Register_32;
   for AIC_IMR'Address use System'To_Address (16#Ffff_F110#);

   --  AIC CISR

   AIC_CISR : Register_32;
   for AIC_CISR'Address use System'To_Address (16#Ffff_F114#);

   --  AIC IECR

   AIC_IECR : Register_32;
   for AIC_IECR'Address use System'To_Address (16#Ffff_F120#);

   --  AIC IDCR

   AIC_IDCR : Register_32;
   for AIC_IDCR'Address use System'To_Address (16#Ffff_F124#);

   --  AIC ICCR

   AIC_ICCR : Register_32;
   for AIC_ICCR'Address use System'To_Address (16#Ffff_F128#);

   --  AIC ISCR

   AIC_ISCR : Register_32;
   for AIC_ISCR'Address use System'To_Address (16#Ffff_F12C#);

   --  AIC EOICR

   AIC_EOICR : Register_32;
   for AIC_EOICR'Address use System'To_Address (16#Ffff_F130#);

   --  AIC SPU

   AIC_SPU : Register_32;
   for AIC_SPU'Address use System'To_Address (16#Ffff_F134#);

   --  AIC DCR

   AIC_DCR : Register_32;
   for AIC_DCR'Address use System'To_Address (16#Ffff_F138#);

   --  AIC FFER

   AIC_FFER : Register_32;
   for AIC_FFER'Address use System'To_Address (16#Ffff_F140#);

   --  AIC FFDR

   AIC_FFDR : Register_32;
   for AIC_FFDR'Address use System'To_Address (16#Ffff_F144#);

   --  AIC FFSR

   AIC_FFSR : Register_32;
   for AIC_FFSR'Address use System'To_Address (16#Ffff_F148#);

   --  PITC

   --  PITC MR

   PITC_PIMR : Register_32;
   for PITC_PIMR'Address use System'To_Address (16#Ffff_FD30#);

   --  PITC SR

   PITC_MISR : Register_32;
   for PITC_MISR'Address use System'To_Address (16#Ffff_FD34#);

   --  PITC PIVR

   PITC_PIVR : Register_32;
   for PITC_PIVR'Address use System'To_Address (16#Ffff_FD38#);

   --  PITC PIIR

   PITC_PIIR : Register_32;
   for PITC_PIIR'Address use System'To_Address (16#Ffff_FD3C#);

   --  TWI

   --  TWI CR

   TWI_CR : Register_32;
   for TWI_CR'Address use System'To_Address (16#Fffb_8000#);

   TWI_START : constant := 2 ** 0;
   TWI_STOP  : constant := 2 ** 1;
   TWI_MSEN  : constant := 2 ** 2;
   TWI_MSDIS : constant := 2 ** 3;
   TWI_SWRST : constant := 2 ** 7;

   --  TWI MMR

   TWI_MMR : Register_32;
   for TWI_MMR'Address use System'To_Address (16#Fffb_8004#);

   TWI_MREAD : constant := 2 ** 12;

   --  TWI IADR

   TWI_IADR : Register_32;
   for TWI_IADR'Address use System'To_Address (16#Fffb_800C#);

   --  TWI CWGR

   TWI_CWGR : Register_32;
   for TWI_CWGR'Address use System'To_Address (16#Fffb_8010#);

   --  TWI SR

   TWI_SR : Register_32;
   for TWI_SR'Address use System'To_Address (16#Fffb_8020#);

   TWI_TXCOMP : constant := 2 ** 0;
   TWI_RXRDY  : constant := 2 ** 1;
   TWI_TXRDY  : constant := 2 ** 2;
   TWI_NACK   : constant := 2 ** 8;

   --  TWI IER

   TWI_IER : Register_32;
   for TWI_IER'Address use System'To_Address (16#Fffb_8024#);

   --  TWI IDR

   TWI_IDR : Register_32;
   for TWI_IDR'Address use System'To_Address (16#Fffb_8028#);

   --  TWI IMR

   TWI_IMR : Register_32;
   for TWI_IMR'Address use System'To_Address (16#Fffb_802C#);

   --  TWI RHR

   TWI_RHR : Register_32;
   for TWI_RHR'Address use System'To_Address (16#Fffb_8030#);

   --  TWI THR

   TWI_THR : Register_32;
   for TWI_THR'Address use System'To_Address (16#Fffb_8034#);

   --  PMC

   --  PMC SCER

   PMC_SCER : Register_32;
   for PMC_SCER'Address use System'To_Address (16#Ffff_fc00#);

   --  PMC SCDR

   PMC_SCDR : Register_32;
   for PMC_SCDR'Address use System'To_Address (16#Ffff_fc04#);

   --  PMC SCSR

   PMC_SCSR : Register_32;
   for PMC_SCSR'Address use System'To_Address (16#Ffff_fc08#);

   --  PMC PCER

   PMC_PCER : Register_32;
   for PMC_PCER'Address use System'To_Address (16#Ffff_fc10#);

   --  PMC PCDR

   PMC_PCDR : Register_32;
   for PMC_PCDR'Address use System'To_Address (16#Ffff_fc14#);

   --  PMC PCSR

   PMC_PCSR : Register_32;
   for PMC_PCSR'Address use System'To_Address (16#Ffff_fc18#);

   --  CKGR MOR

   CKGR_MOR : Register_32;
   for CKGR_MOR'Address use System'To_Address (16#Ffff_fc20#);

   --  CKGR MCFR

   CKGR_MCFR : Register_32;
   for CKGR_MCFR'Address use System'To_Address (16#Ffff_fc24#);

   --  CKGR PLLR

   CKGR_PLLR : Register_32;
   for CKGR_PLLR'Address use System'To_Address (16#Ffff_fc2c#);

   --  PMC MCKR

   PMC_MCKR : Register_32;
   for PMC_MCKR'Address use System'To_Address (16#Ffff_fc30#);

   --  PMC PCK0

   PMC_PCK0 : Register_32;
   for PMC_PCK0'Address use System'To_Address (16#Ffff_fc40#);

   --  PMC PCK1

   PMC_PCK1 : Register_32;
   for PMC_PCK1'Address use System'To_Address (16#Ffff_fc44#);

   --  PMC PCK2

   PMC_PCK2 : Register_32;
   for PMC_PCK2'Address use System'To_Address (16#Ffff_fc48#);

   --  PMC IER

   PMC_IER : Register_32;
   for PMC_IER'Address use System'To_Address (16#Ffff_fc60#);

   --  PMC IDR

   PMC_IDR : Register_32;
   for PMC_IDR'Address use System'To_Address (16#Ffff_fc64#);

   --  PMC SR

   PMC_SR : Register_32;
   for PMC_SR'Address use System'To_Address (16#Ffff_fc68#);

   --  PMC IMR

   PMC_IMR : Register_32;
   for PMC_IMR'Address use System'To_Address (16#Ffff_fc6C#);

   --  PIOA

   --  PIO PER

   PIOA_PER : Register_32;
   for PIOA_PER'Address use System'To_Address (16#Ffff_f400#);

   --  PIO PDR

   PIOA_PDR : Register_32;
   for PIOA_PDR'Address use System'To_Address (16#Ffff_f404#);

   --  PIO PSR

   PIOA_PSR : Register_32;
   for PIOA_PSR'Address use System'To_Address (16#Ffff_f408#);

   --  PIO OER

   PIOA_OER : Register_32;
   for PIOA_OER'Address use System'To_Address (16#Ffff_f410#);

   --  PIO ODR

   PIOA_ODR : Register_32;
   for PIOA_ODR'Address use System'To_Address (16#Ffff_f414#);

   --  PIO OSR

   PIOA_OSR : Register_32;
   for PIOA_OSR'Address use System'To_Address (16#Ffff_f418#);

   --  PIO IFER

   PIOA_IFER : Register_32;
   for PIOA_IFER'Address use System'To_Address (16#Ffff_f420#);

   --  PIO IFDR

   PIOA_IFDR : Register_32;
   for PIOA_IFDR'Address use System'To_Address (16#Ffff_f424#);

   --  PIO IFSR

   PIOA_IFSR : Register_32;
   for PIOA_IFSR'Address use System'To_Address (16#Ffff_f428#);

   --  PIO SODR

   PIOA_SODR : Register_32;
   for PIOA_SODR'Address use System'To_Address (16#Ffff_f430#);

   --  PIO CODR

   PIOA_CODR : Register_32;
   for PIOA_CODR'Address use System'To_Address (16#Ffff_f434#);

   --  PIO ODSR

   PIOA_ODSR : Register_32;
   for PIOA_ODSR'Address use System'To_Address (16#Ffff_f438#);

   --  PIO PDSR

   PIOA_PDSR : Register_32;
   for PIOA_PDSR'Address use System'To_Address (16#Ffff_f43c#);

   --  PIO IER

   PIOA_IER : Register_32;
   for PIOA_IER'Address use System'To_Address (16#Ffff_f440#);

   --  PIO IDR

   PIOA_IDR : Register_32;
   for PIOA_IDR'Address use System'To_Address (16#Ffff_f444#);

   --  PIO IMR

   PIOA_IMR : Register_32;
   for PIOA_IMR'Address use System'To_Address (16#Ffff_f448#);

   --  PIO ISR

   PIOA_ISR : Register_32;
   for PIOA_ISR'Address use System'To_Address (16#Ffff_f44c#);

   --  PIO MDER

   PIOA_MDER : Register_32;
   for PIOA_MDER'Address use System'To_Address (16#Ffff_f450#);

   --  PIO MDDR

   PIOA_MDDR : Register_32;
   for PIOA_MDDR'Address use System'To_Address (16#Ffff_f454#);

   --  PIO MDSR

   PIOA_MDSR : Register_32;
   for PIOA_MDSR'Address use System'To_Address (16#Ffff_f458#);

   --  PIO PUDR

   PIOA_PUDR : Register_32;
   for PIOA_PUDR'Address use System'To_Address (16#Ffff_f460#);

   --  PIO PUER

   PIOA_PUER : Register_32;
   for PIOA_PUER'Address use System'To_Address (16#Ffff_f464#);

   --  PIO PUSR

   PIOA_PUSR : Register_32;
   for PIOA_PUSR'Address use System'To_Address (16#Ffff_f468#);

   --  PIO ASR

   PIOA_ASR : Register_32;
   for PIOA_ASR'Address use System'To_Address (16#Ffff_f470#);

   --  PIO BSR

   PIOA_BSR : Register_32;
   for PIOA_BSR'Address use System'To_Address (16#Ffff_f474#);

   --  PIO ABSR

   PIOA_ABSR : Register_32;
   for PIOA_ABSR'Address use System'To_Address (16#Ffff_f478#);

   --  PIO OWER

   PIOA_OWER : Register_32;
   for PIOA_OWER'Address use System'To_Address (16#Ffff_f4a0#);

   --  PIO OWDR

   PIOA_OWDR : Register_32;
   for PIOA_OWDR'Address use System'To_Address (16#Ffff_f4a4#);

   --  PIO OWSR

   PIOA_OWSR : Register_32;
   for PIOA_OWSR'Address use System'To_Address (16#Ffff_f4a8#);

   --  SPI

   --  SPI CR

   SPI_CR : Register_32;
   for SPI_CR'Address use System'To_Address (16#Fffe_0000#);

   SPI_SPIEN  : constant := 2 ** 0;
   SPI_SPIDIS : constant := 2 ** 1;
   SPI_SWRST  : constant := 2 ** 7;

   --  SPI MR

   SPI_MR : Register_32;
   for SPI_MR'Address use System'To_Address (16#Fffe_0004#);

   SPI_MSTR   : constant := 2 ** 0;
   SPI_DLYBCS : constant := 2 ** 24;

   --  SPI RDR

   SPI_RDR : Register_32;
   for SPI_RDR'Address use System'To_Address (16#Fffe_0008#);

   --  SPI TDR

   SPI_TDR : Register_32;
   for SPI_TDR'Address use System'To_Address (16#Fffe_000c#);

   --  SPI SR

   SPI_SR : Register_32;
   for SPI_SR'Address use System'To_Address (16#Fffe_0010#);

   SPI_ENDTX : constant := 2 ** 5;
   SPI_TXEMPTY : constant := 2 ** 9;

   --  SPI IER

   SPI_IER : Register_32;
   for SPI_IER'Address use System'To_Address (16#Fffe_0014#);

   --  SPI IDR

   SPI_IDR : Register_32;
   for SPI_IDR'Address use System'To_Address (16#Fffe_0018#);

   --  SPI IMR

   SPI_IMR : Register_32;
   for SPI_IMR'Address use System'To_Address (16#Fffe_001c#);

   --  SPI CSR0

   SPI_CSR0 : Register_32;
   for SPI_CSR0'Address use System'To_Address (16#Fffe_0030#);

   --  SPI CSR1

   SPI_CSR1 : Register_32;
   for SPI_CSR1'Address use System'To_Address (16#Fffe_0034#);

   --  SPI CSR2

   SPI_CSR2 : Register_32;
   for SPI_CSR2'Address use System'To_Address (16#Fffe_0038#);

   --  SPI CSR3

   SPI_CSR3 : Register_32;
   for SPI_CSR3'Address use System'To_Address (16#Fffe_003c#);

   --  SPI (PDC) RPR

   SPI_RPR : Register_32;
   for SPI_RPR'Address use System'To_Address (16#Fffe_0100#);

   --  SPI (PDC) RCR

   SPI_RCR : Register_32;
   for SPI_RCR'Address use System'To_Address (16#Fffe_0104#);

   --  SPI (PDC) TPR

   SPI_TPR : Register_32;
   for SPI_TPR'Address use System'To_Address (16#Fffe_0108#);

   --  SPI (PDC) TCR

   SPI_TCR : Register_32;
   for SPI_TCR'Address use System'To_Address (16#Fffe_010c#);

   --  SPI (PDC) RNPR

   SPI_RNPR : Register_32;
   for SPI_RNPR'Address use System'To_Address (16#Fffe_0110#);

   --  SPI (PDC) RNCR

   SPI_RNCR : Register_32;
   for SPI_RNCR'Address use System'To_Address (16#Fffe_0114#);

   --  SPI (PDC) TNPR

   SPI_TNPR : Register_32;
   for SPI_TNPR'Address use System'To_Address (16#Fffe_0118#);

   --  SPI (PDC) TNCR

   SPI_TNCR : Register_32;
   for SPI_TNCR'Address use System'To_Address (16#Fffe_011c#);

   --  SPI (PDC) PTCR

   SPI_PTCR : Register_32;
   for SPI_PTCR'Address use System'To_Address (16#Fffe_0120#);

   SPI_TXTEN : constant := 2 ** 8;

   --  SPI (PDC) PTSR

   SPI_PTSR : Register_32;
   for SPI_PTSR'Address use System'To_Address (16#Fffe_0124#);

   --  ADC

   --  ADC CR

   ADC_CR : Register_32;
   for ADC_CR'Address use System'To_Address (16#Fffd_8000#);

   --  ADC MR

   ADC_MR : Register_32;
   for ADC_MR'Address use System'To_Address (16#Fffd_8004#);

   --  ADC CHER

   ADC_CHER : Register_32;
   for ADC_CHER'Address use System'To_Address (16#Fffd_8010#);

   --  ADC CHDR

   ADC_CHDR : Register_32;
   for ADC_CHDR'Address use System'To_Address (16#Fffd_8014#);

   --  ADC CHSR

   ADC_CHSR : Register_32;
   for ADC_CHSR'Address use System'To_Address (16#Fffd_8018#);

   --  ADC SR

   ADC_SR : Register_32;
   for ADC_SR'Address use System'To_Address (16#Fffd_801C#);

   --  ADC LCDR

   ADC_LCDR : Register_32;
   for ADC_LCDR'Address use System'To_Address (16#Fffd_8020#);

   --  ADC IER

   ADC_IER : Register_32;
   for ADC_IER'Address use System'To_Address (16#Fffd_8024#);

   --  ADC IDR

   ADC_IDR : Register_32;
   for ADC_IDR'Address use System'To_Address (16#Fffd_8028#);

   --  ADC IMR

   ADC_IMR : Register_32;
   for ADC_IMR'Address use System'To_Address (16#Fffd_802c#);

   --  ADC CDR

   ADC_CDR : array (0 .. 7) of Register_32;
   for ADC_CDR'Address use System'To_Address (16#Fffd_8030#);

   --  ADC CDR0

   ADC_CDR0 : Register_32;
   for ADC_CDR0'Address use System'To_Address (16#Fffd_8030#);

   --  ADC CDR1

   ADC_CDR1 : Register_32;
   for ADC_CDR1'Address use System'To_Address (16#Fffd_8034#);

   --  ADC CDR2

   ADC_CDR2 : Register_32;
   for ADC_CDR2'Address use System'To_Address (16#Fffd_8038#);

   --  ADC CDR3

   ADC_CDR3 : Register_32;
   for ADC_CDR3'Address use System'To_Address (16#Fffd_803c#);

   --  ADC CDR4

   ADC_CDR4 : Register_32;
   for ADC_CDR4'Address use System'To_Address (16#Fffd_8040#);

   --  ADC CDR5

   ADC_CDR5 : Register_32;
   for ADC_CDR5'Address use System'To_Address (16#Fffd_8044#);

   --  ADC CDR6

   ADC_CDR6 : Register_32;
   for ADC_CDR6'Address use System'To_Address (16#Fffd_8048#);

   --  ADC CDR7

   ADC_CDR7 : Register_32;
   for ADC_CDR7'Address use System'To_Address (16#Fffd_804c#);

   --  UDP

   --  UDP FRM_NUM

   UDP_FRM_NUM : Register_32;
   for UDP_FRM_NUM'Address use System'To_Address (16#Fffb_0000#);

   --  UDP GLB_STAT

   UDP_GLB_STAT : Register_32;
   for UDP_GLB_STAT'Address use System'To_Address (16#Fffb_0004#);

   UDP_FADDEN : constant := 2 ** 0;
   UDP_CONFG  : constant := 2 ** 1;

   --  UDP FADDR

   UDP_FADDR : Register_32;
   for UDP_FADDR'Address use System'To_Address (16#Fffb_0008#);

   UDP_FEN : constant := 2 ** 8;

   --  UDP IER

   UDP_IER : Register_32;
   for UDP_IER'Address use System'To_Address (16#Fffb_0010#);

   --  UDP IDR

   UDP_IDR : Register_32;
   for UDP_IDR'Address use System'To_Address (16#Fffb_0014#);

   --  UDP IMR

   UDP_IMR : Register_32;
   for UDP_IMR'Address use System'To_Address (16#Fffb_0018#);

   --  UDP ISR

   UDP_ISR : Register_32;
   for UDP_ISR'Address use System'To_Address (16#Fffb_001c#);

   UDP_WAKEUP    : constant := 2 ** 13;
   UDP_ENDBUSRES : constant := 2 ** 12;
   UDP_SOFINT    : constant := 2 ** 11;
   UDP_RXRSM     : constant := 2 ** 9;
   UDP_RXSUSP    : constant := 2 ** 8;
   UDP_EP3       : constant := 2 ** 3;
   UDP_EP2       : constant := 2 ** 2;
   UDP_EP1       : constant := 2 ** 1;
   UDP_EP0       : constant := 2 ** 0;

   --  UDP ICR

   UDP_ICR : Register_32;
   for UDP_ICR'Address use System'To_Address (16#Fffb_0020#);

   --  UDP RST_EP

   UDP_RST_EP : Register_32;
   for UDP_RST_EP'Address use System'To_Address (16#Fffb_0028#);

   --  UDP CSR0

   UDP_CSR0 : Register_32;
   for UDP_CSR0'Address use System'To_Address (16#Fffb_0030#);

   UDP_EPEDS           : constant := 2 ** 15;
   UDP_DTGLE           : constant := 2 ** 11;
   UDP_EPTYPE_CTRL     : constant := 0 * 2 ** 8;
   UDP_EPTYPE_ISO_OUT  : constant := 1 * 2 ** 8;
   UDP_EPTYPE_ISO_IN   : constant := 5 * 2 ** 8;
   UDP_EPTYPE_BULK_OUT : constant := 2 * 2 ** 8;
   UDP_EPTYPE_BULK_IN  : constant := 6 * 2 ** 8;
   UDP_EPTYPE_INT_OUT  : constant := 3 * 2 ** 8;
   UDP_EPTYPE_INT_IN   : constant := 7 * 2 ** 8;
   UDP_DIR             : constant := 2 ** 7;
   UDP_RX_DATA_BK1 : constant := 2 ** 6;
   UDP_FORCE_STALL : constant := 2 ** 5;
   UDP_TXPKTRDY    : constant := 2 ** 4;
   UDP_STALLSENT   : constant := 2 ** 3;
   UDP_ISOERROR    : constant := 2 ** 3;
   UDP_RXSETUP     : constant := 2 ** 2;
   UDP_RX_DATA_BK0 : constant := 2 ** 1;
   UDP_TXCOMP      : constant := 2 ** 0;

   --  UDP CSR1

   UDP_CSR1 : Register_32;
   for UDP_CSR1'Address use System'To_Address (16#Fffb_0034#);

   --  UDP CSR2

   UDP_CSR2 : Register_32;
   for UDP_CSR2'Address use System'To_Address (16#Fffb_0038#);

   --  UDP CSR3

   UDP_CSR3 : Register_32;
   for UDP_CSR3'Address use System'To_Address (16#Fffb_003c#);

   --  UDP FDR0

   UDP_FDR0 : Register_32;
   for UDP_FDR0'Address use System'To_Address (16#Fffb_0050#);

   --  UDP FDR1

   UDP_FDR1 : Register_32;
   for UDP_FDR1'Address use System'To_Address (16#Fffb_0054#);

   --  UDP FDR2

   UDP_FDR2 : Register_32;
   for UDP_FDR2'Address use System'To_Address (16#Fffb_0058#);

   --  UDP FDR3

   UDP_FDR3 : Register_32;
   for UDP_FDR3'Address use System'To_Address (16#Fffb_005c#);

   --  UDP TXVC

   UDP_TXVC : Register_32;
   for UDP_TXVC'Address use System'To_Address (16#Fffb_0000#);

end System.BB.Peripherals.Registers;
