------------------------------------------------------------------------------
--                                                                          --
--                       Copyright (C) 2010, AdaCore                        --
--                                                                          --
-- This  is  free  software;  you  can  redistribute  it and/or  modify  it --
-- under terms of the  GNU General Public License as published  by the Free --
-- Software  Foundation;  either version 2,  or (at your option)  any later --
-- version.  This  is  distributed  in the hope that  it  will  be  useful, --
-- but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANT- --
-- ABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public --
-- License for  more details.  You should have  received  a copy of the GNU --
-- General Public License distributed with GNATStack;  see file COPYING. If --
-- not, write to the  Free Software Foundation,  51 Franklin Street,  Fifth --
-- Floor, Boston, MA 02110-1301, USA.                                       --
------------------------------------------------------------------------------

with Nxt.Display;
with Nxt.Avrtask; use Nxt.Avrtask;
with Nxt.Avr_Types; use Nxt.Avr_Types;
with Nxt.Motorwheels;
with Menus; use Menus;

package body Menu_Motors is
   type Speed_Array is array (Motor_Id) of Pwm_Type;
   Cur_Motor : Motor_Id := Motor_A;
   Speeds : Speed_Array := (others => 0);
   Step : constant Pwm_Type := 20;

   procedure Put_Motor_Id (Id : Motor_Id) is
      use Nxt.Display;
   begin
      Put_Noupdate (Character'Val (Character'Pos ('A') + Motor_Id'Pos (Id)));
   end Put_Motor_Id;

   procedure Next_Motor is
   begin
      if Cur_Motor = Motor_Id'Last then
         Cur_Motor := Motor_Id'First;
      else
         Cur_Motor := Motor_Id'Succ (Cur_Motor);
      end if;
   end Next_Motor;

   procedure Select_Next_Motor is
      use Nxt.Display;
   begin
      Next_Motor;
      Put_Noupdate ("Motor ");
      Put_Motor_Id (Cur_Motor);
      Screen_Update;
      Wait_Key;
   end Select_Next_Motor;

   procedure Select_Motor_B is
   begin
      Cur_Motor := Motor_B;
   end Select_Motor_B;

   procedure Select_Motor_C is
   begin
      Cur_Motor := Motor_C;
   end Select_Motor_C;

   procedure Speed_Up is
   begin
      if Speeds (Cur_Motor) < Pwm_Type'Last - Step then
         Speeds (Cur_Motor) := Speeds (Cur_Motor) + Step;
      else
         Speeds (Cur_Motor) := Pwm_Type'Last;
      end if;
      Set_Motor (Cur_Motor, Speeds (Cur_Motor), False);
   end Speed_Up;

   procedure Speed_Down is
   begin
      if Speeds (Cur_Motor) > Pwm_Type'First + Step then
         Speeds (Cur_Motor) := Speeds (Cur_Motor) - Step;
      else
         Speeds (Cur_Motor) := Pwm_Type'First;
      end if;
      Set_Motor (Cur_Motor, Speeds (Cur_Motor), False);
   end Speed_Down;

   procedure Stop is
   begin
      Speeds (Cur_Motor) := 0;
      Set_Motor (Cur_Motor, Speeds (Cur_Motor), True);
   end Stop;

   procedure Break is
   begin
      Speeds (Cur_Motor) := 0;
      Set_Motor (Cur_Motor, Speeds (Cur_Motor), False);
   end Break;

   procedure Stop_All is
   begin
      for I in Motor_Id'Range loop
         Speeds (I) := 0;
         Set_Motor (I, Speeds (I), False);
      end loop;
   end Stop_All;

   procedure Show_Positions is
      use Nxt.Display;
      Last_Button : Button_Kind := Button;
   begin
      loop
         Clear_Noupdate;
         for I in Motor_Id'Range loop
            Put_Motor_Id (i);
            Put_Noupdate (": ");
            Put_Noupdate (Nxt.Motorwheels.Positions (I));
            Newline_Noupdate;
         end loop;
         Newline_Noupdate;
         Put_Noupdate ("Motor: ");
         Put_Motor_Id (Cur_Motor);
         Screen_Update;
         Wait_Ms;
         if Button /= Last_Button then
            case Button is
               when Button_Power =>
                  exit;
               when Button_Left =>
                  Speed_Down;
               when Button_Right =>
                  Speed_Up;
               when Button_Middle =>
                  Break;
               when Button_None =>
                  null;
            end case;
            Last_Button := Button;
         end if;
      end loop;
   end Show_Positions;

   subtype S is String;

   Menu : constant Menu_Type :=
     (
      (new S'("Sel next motor"), Select_Next_Motor'Access),
      (new S'("Speed up"), Speed_Up'Access),
      (new S'("Speed down"), Speed_Down'Access),
      (new S'("Stop"), Stop'Access),
      (new S'("Break"), Break'Access),
      (new S'("Stop all"), Stop_All'Access),
      (new S'("Positions"), Show_Positions'Access)
     );

   procedure Do_Menu_Motors is
   begin
      Play_Menu (Menu);
   end Do_Menu_Motors;

end Menu_Motors;
