------------------------------------------------------------------------------
--                                                                          --
--                       Copyright (C) 2010, AdaCore                        --
--                                                                          --
-- This  is  free  software;  you  can  redistribute  it and/or  modify  it --
-- under terms of the  GNU General Public License as published  by the Free --
-- Software  Foundation;  either version 2,  or (at your option)  any later --
-- version.  This  is  distributed  in the hope that  it  will  be  useful, --
-- but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANT- --
-- ABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public --
-- License for  more details.  You should have  received  a copy of the GNU --
-- General Public License distributed with GNATStack;  see file COPYING. If --
-- not, write to the  Free Software Foundation,  51 Franklin Street,  Fifth --
-- Floor, Boston, MA 02110-1301, USA.                                       --
------------------------------------------------------------------------------

with Interfaces; use Interfaces;
with Ada.Real_Time; use Ada.Real_Time;
with Nxt.Display; use Nxt.Display;
with Nxt.Avr_Types;
with Nxt.Avrtask;
with Menus; use Menus;
with Menu_Bt;
with Menu_Motors;

with Nxt.Motorwheels;

package body Menu_Tests is

   procedure Test_Buttons
   is
      use Nxt.Avr_Types;
      use Nxt.Avrtask;

      T : Time;
      Cnt : Unsigned_8;
   begin
      T := Clock;
      Cnt := 0;
      loop
         Put_Hex (Cnt);
         Put (' ');
         case Button is
            when Button_Left =>
               Put ('L');
            when Button_Middle =>
               Put ('M');
            when Button_Right =>
               Put ('R');
            when Button_Power =>
               Put ('P');
            when Button_None =>
               Put ('-');
         end case;
         Put (Ascii.CR);
         Cnt := Cnt + 1;
         T := T + Milliseconds (1 * 200);
         delay until T;
         if Button = Button_Power then
            return;
         end if;
      end loop;
   end Test_Buttons;

   procedure Test_Sensors
   is
      use Nxt.Avr_Types;
      use Nxt.Avrtask;

      T : Time;
      Cnt : Unsigned_8;
   begin
      T := Clock;
      Cnt := 0;
      loop
         Clear_Noupdate;
         for I in Sensor_Id'Range loop
            Put_Noupdate
              (Character'Val (Character'Pos ('1') + Sensor_Id'Pos (I)));
            Put_Noupdate (' ');
            Put_Hex (Get_Sensor (I));
            Newline_Noupdate;
         end loop;
         Screen_Update;
         Cnt := Cnt + 1;
         T := T + Milliseconds (1 * 500);
         delay until T;
         if Button = Button_Power then
            return;
         end if;
      end loop;
   end Test_Sensors;

   subtype S is String;

   Menu : constant Menu_Type :=
     (
      (new S'("buttons"), Test_Buttons'Access),
      (new S'("sensors"), Test_Sensors'Access),
      (new S'("bluetooth"), Menu_Bt.Do_Menu_Bt'Access),
      (new S'("motors"), Menu_Motors.Do_Menu_Motors'Access),
      (new S'("Power off"), Nxt.Avrtask.Power_Down'Access)
     );

   procedure Do_Menu_Tests is
   begin
      Play_Menu (Menu);
   end Do_Menu_Tests;
end Menu_Tests;
