------------------------------------------------------------------------------
--                                                                          --
--                       Copyright (C) 2010, AdaCore                        --
--                                                                          --
-- This  is  free  software;  you  can  redistribute  it and/or  modify  it --
-- under terms of the  GNU General Public License as published  by the Free --
-- Software  Foundation;  either version 2,  or (at your option)  any later --
-- version.  This  is  distributed  in the hope that  it  will  be  useful, --
-- but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANT- --
-- ABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public --
-- License for  more details.  You should have  received  a copy of the GNU --
-- General Public License distributed with GNATStack;  see file COPYING. If --
-- not, write to the  Free Software Foundation,  51 Franklin Street,  Fifth --
-- Floor, Boston, MA 02110-1301, USA.                                       --
------------------------------------------------------------------------------

with Ada.Real_Time; use Ada.Real_Time;
with Nxt.Display; use Nxt.Display;
with Nxt.Avrtask; use Nxt.Avrtask;

package body Menus is
   function Wait_Key return Defined_Button_Kind is
      But : Button_Kind;
   begin
      --  Wait until no key pressed.
      loop
         exit when Button = Button_None;
         Wait_Ms;
      end loop;

      Put ('B');

      --  Wait until a key is pressed.
      loop
         But := Button;
         if But /= Button_None then
            return But;
         end if;
         Wait_Ms;
      end loop;
   end Wait_Key;

   procedure Play_Menu (M : Menu_Type) is
      Item : Natural := M'First;
   begin
      loop
         --  Display the menu.
         Clear_Noupdate;

         for I in M'Range loop
            if I = Item then
               Put_Noupdate ('*');
            else
               Put_Noupdate (' ');
            end if;
            Put_Noupdate (M (I).Name.all);
            Newline_Noupdate;
         end loop;
         Screen_Update;

         case Wait_Key is
            when Button_Left =>
               Put ('L');
               if Item > M'First then
                  Item := Item - 1;
               else
                  Item := M'Last;
               end if;
            when Button_Right =>
               Put ('R');
               if Item < M'Last then
                  Item := Item + 1;
               else
                  Item := M'First;
               end if;
            when Button_Power =>
               Put ('P');
               exit;
            when Button_Middle =>
               Put ('M');
               M (Item).Handler.all;
         end case;
      end loop;
   end Play_Menu;

   procedure Wait_Ms is
   begin
      delay until Clock + Milliseconds (10);
   end Wait_Ms;

   procedure Wait_Key is
   begin
      Put ("Press button");

      loop
         exit when Button = Button_None;
         Wait_Ms;
      end loop;

      loop
         exit when Button /= Button_None;
         Wait_Ms;
      end loop;
   end Wait_Key;

end Menus;
